library(lme4)
library(MASS)
library(dplyr)
library(forcats)
library(gridExtra)

#Chown, S.L., Bergstrom, D. M., Houghton, M., Kiefer, K., Terauds, A. and R. I. Leihy. Invasive species impacts on sub-Antarctic Collembola support the Antarctic climate-diversity-invasion hypothesis

###Code for:
#1. Initial overview of number of sites with incomplete environmental data
#2. Data transformation for analysis (rescaling continuous predictors, reordering qualitative factors, converting aspect from degrees to degrees from south)
#3. GLMM for springtail richness ~ environmental variables + site code as a random effect to account for hierarchical sampling design (3-4 cores taken per site, multiple sites per locality)
#4. GLMM for springtail abundance ~ environmental variables + site code as a random effect to account for hierarchical sampling design (3-4 cores taken per site, multiple sites per locality)
#5. GLM for multivariate abundance data

#set.wd()
data1<- read.csv("/HeardIsland_springtails_dataset.csv")


data1_excluded<- subset(data1, !data1$Exclusion_Criteria=="none") ##excluding three sites with incomplete environmental data from richness and abundance analyses
data1<- subset(data1, data1$Exclusion_Criteria=="none")


##creating a unique site code (so that within and between cushion samples from same site are grouped in random effect variable. This is necessary because cores were taken from open cushion carpet within cushions and between cushions at the same sites, but given different habitat types (habitat code 3-4, 5-6) and site codes, yet the coordinates and environmental data are the same)
data_temp<- unique(subset(data1, select=c(Longitude_final, Latitude_final)))
data_temp$unique_site<- 1:nrow(data_temp)
data1<- merge(data1, data_temp, by= c("Longitude_final", "Latitude_final"))
data1$Site.code<- factor(data1$Site.code)
data1$unique_site<- factor(data1$unique_site)
rm(data_temp)


data1$Location_code<- as.factor(data1$Location_code)
data1$Habitat_type<- as.factor(data1$Habitat_type)
data1$Site.code<- as.factor(data1$Site.code)

#quick exploratory plots
par(mfrow= c(2,2))
boxplot(data1$Core_abundance ~ data1$Exposure_Scale)
boxplot(data1$Core_abundance ~ data1$Water_Scale)
plot(data1$Location_code)
boxplot(data1$Altitude_masl ~ data1$Habitat_type)


##simplifying habitat type since elevation is its own predictor in analysis (e.g. habitat type 1 "Closed cushion carpet_high altitude" and habitat type 2 "Closed cushion carpet_low altitude" will become "Closed cushion carpet", and elevation will also be included as a variable)
data1$Habitat_simplified<- data1$Habitat_type

data1<- data1 %>%  mutate(Habitat_simplified = fct_collapse(Habitat_simplified,
                              "Closed cushion carpet" = c("Closed cushion carpet_high altitude","Closed cushion carpet_low altitude"),
                              "Mossy fellfield" = c("Mossy fellfield_low altitude", "Mossy fellfield_mid altitude", "Mossy fellfield_high altitude"),
                              "Open cushion carpet" = c("Open cushion carpet_Cushions_high altitude", "Open cushion carpet_Cushions_low altitude"),
                              "Between open cushion carpet" = c("Open cushion carpet_between cushions_high altitude", "Open cushion carpet_between cushions_low altitude"))) 


###reorder vegetation factor so that comparisons are made with habitat type with the highest overall springtail abundance (Coastal Biotic Vegetation)
data1$Habitat_simplified<- factor(data1$Habitat_simplified, levels= c("Coastal Biotic vegetation", "Pringlea", "Drainage line", "Acaena", "Closed cushion carpet", "Mossy fellfield", "Open cushion carpet", "Between open cushion carpet", "Scoria/moraine/unvegetated slopes"))


#convert aspect from degrees (0-360) to degrees from south (0-180) (because north-south differences are biologically most relevant here due to differences in exposure/radiation, and western-facing sites were not well surveyed due to accessibility, so east-west differences are poorly represented in the survey)
data1$Aspect_deg_fromSouth<- data1$Aspect_deg
east<- subset(data1, data1$Aspect_deg<180)
east$Aspect_deg_fromSouth= 180-east$Aspect_deg
#south<- subset(data1, data1$Aspect_deg==180) #no sites exactly south-facing (aspect= 180)
west<- subset(data1, data1$Aspect_deg>180)
west$Aspect_deg_fromSouth= west$Aspect_deg-180
data1<- rbind(east, west)
rm(east, west)


##global model, all environmental variables
##Location (e.g. Spit Bay, Fairchild Beach) and Site included as random effects to account for hierarchical survey design: four main localities, within each on which are 28 sites, within each of which 3-8 cores were taken
m.pois<- glmer(Core_richness ~  Habitat_simplified  + Altitude_masl + Slope_deg + Aspect_deg_fromSouth+ Water_Scale+ Exposure_Scale+ (1 | Location_code/unique_site), data=data1, family = poisson(link=log))
summary(m.pois)
##Error: "Model is nearly unidentifiable: large eigenvalue ratio- Rescale variables?"

###recommended to rescale continuous variables for analysis (see model error warnings)
data1$Altitude_rescale<- scale(data1$Altitude_masl, center = TRUE, scale = TRUE)
data1$Slope_rescale<- scale(data1$Slope_deg, center = TRUE, scale = TRUE)
data1$Aspect_south_rescale<- scale(data1$Aspect_deg_fromSouth, center = TRUE, scale = TRUE)


m.pois<- glmer(Core_richness ~  Habitat_simplified  + Altitude_rescale + Slope_rescale+ Aspect_south_rescale+ Water_Scale+ Exposure_Scale + (1 | Location_code/unique_site), data=data1, family = poisson(link=log))
summary(m.pois)
#Model failed to converge with max|grad| = 0.00430316 (tol = 0.002, component 1)

##Following advice about model optimisation from: https://rstudio-pubs-static.s3.amazonaws.com/33653_57fc7b8e5d484c909b615d8633c01d51.html
#restart the convergence from the previous fit, and try a difference optimizer
ss <- getME(m.pois,c("theta","fixef"))
m3 <- update(m.pois,start=ss,control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(m3)

#Model simplification (following procedure used in Zuur et al. 2009 Mixed Effects Models and Extensions in Ecology with R)
drop1(m3, test = "Chi") ##Habitat_simplified is the most important variable


m.pois_simp<- glmer(Core_richness ~  Habitat_simplified  + (1 | Location_code/unique_site), data=data1, family = poisson(link=log), control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(m.pois_simp)

overdisp_fun <- function(model) {
  rdf <- df.residual(model)
  rp <- residuals(model,type="pearson")
  Pearson.chisq <- sum(rp^2)
  prat <- Pearson.chisq/rdf
  pval <- pchisq(Pearson.chisq, df=rdf, lower.tail=FALSE)
  c(chisq=Pearson.chisq,ratio=prat,rdf=rdf,p=pval)
}

overdisp_fun(m.pois_simp)
m.pois_simp
qqnorm(residuals(m.pois_simp))
summary(m.pois_simp)
saveRDS(m.pois_simp, file = "/GLMM_richness_v1.rds")


##plotting outcome
fitted_values <- data.frame(fitted(m.pois_simp, level = 0), data1$Habitat_simplified)
par(mfrow= c(2,1))
boxplot(fitted_values$fitted.m.pois_simp..level...0.~ fitted_values$data1.Habitat_simplified, ylab = "Fitted Richness", xlab = "Habitat")
boxplot(data1$Core_richness~ data1$Habitat_simplified, ylab = "Observed Richness", xlab = "Habitat")
rm(ss, m3, fitted_values)


################################################################################################################################################
################################################################################################################################################
##abundance data
hist(data1$Core_abundance, breaks= 100)

m.pois_abund<- glmer(Core_abundance ~  Habitat_simplified  + Altitude_rescale + Slope_rescale+ Aspect_south_rescale+ Water_Scale+ Exposure_Scale+ (1 | Location_code/unique_site), data=data1, family = poisson(link=log), control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
drop1(m.pois_abund, test = "Chi") ##Habitat type (simplified) and exposure scale most important predictors of abundance

m.pois_abund_simp<- glmer(Core_abundance ~  Habitat_simplified  + Exposure_Scale +  (1 | Location_code/unique_site), data=data1, family = poisson(link=log), control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

overdisp_fun(m.pois_abund_simp) ##overdispered, use negative binomial distribution instead

m.pois_abund_nb<- glmer.nb(Core_abundance ~  Habitat_simplified  + Altitude_rescale + Slope_rescale+ Aspect_south_rescale+ Water_Scale+ Exposure_Scale+ (1 | Location_code/unique_site), data=data1,  control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
drop1(m.pois_abund_nb, test = "Chi")  ##Habitat type (simplified) most important predictors of abundance


m.pois_abund_simp_nb<- glmer.nb(Core_abundance ~  Habitat_simplified  +  (1 | Location_code/unique_site), data=data1, control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))
summary(m.pois_abund_simp_nb)
qqnorm(residuals(m.pois_abund_simp_nb))

## The neg.binomial theta parameter:
getME(m.pois_abund_simp_nb, "glmer.nb.theta")
LL <- logLik(m.pois_abund_simp_nb)
LL


##plotting outcome
fitted_values <- data.frame(fitted(m.pois_abund_simp_nb, level = 0), data1$Habitat_simplified)
par(mfrow= c(2,1))
boxplot(fitted_values$fitted.m.pois_abund_simp_nb..level...0.~ fitted_values$data1.Habitat_simplified, ylab = "Fitted Abundance", xlab = "Habitat")
boxplot(data1$Core_abundance~ data1$Habitat_simplified, ylab = "Observed Abundance", xlab = "Habitat")

rm(fitted_values)


saveRDS(m.pois_abund_simp_nb, file = "/GLMM_abundance_nb_v1.rds")


rm(data1_excluded, m.pois, m.pois_abund, m.pois_abund_nb, m.pois_abund_simp, m.pois_abund_simp_nb, m.pois_simp, LL)


################################################################################################################################################
################################################################################################################################################
###GLM for multivariate abundance data

library(mvabund)
library(tidyverse)

##Excluding unvegetated scoria/moraine slopes from analysis (total abundance 37 individuals)
data1<- subset(data1, !data1$Habitat_simplified =="Scoria/moraine/unvegetated slopes")

##Aggregating core data to a site level, because of non-independence of cores within sites (violates mvabund model assumptions)
data2_species<- subset(data1, select= c(Site.code, Cryptogygus.antarcticus,Cryptopygus.tricuspis, Mucrosomia.caeca,Folsomotoma.punctata, Isotoma.sp...small.white., Megalothorax.sp., Tullbergia.bisetosa, Tullbergia.templei, Friesea.bispinosa, Unknown, Folsomotoma.octooculata, Friesea.tilbrooki, Archistoma.brucei,  Tullbergia.antarctica))
data2_sites<- subset(data1, select= c(Site.code, Latitude_final, Longitude_final, Location, Locality, Site.name, Water_Scale, Exposure_Scale, Slope_deg, Aspect_deg, Altitude_masl,  Blocks...25cm., Pebbles..5cm...25cm., Gravel..0.2...5cm., Sand.and.finer.material...0.2cm., Location_code, Habitat_code, Habitat_type, Habitat_simplified, Aspect_deg_fromSouth, unique_site))

data2_species1<- data2_species %>% group_by(Site.code) %>% summarise(across(everything(), sum, na.rm=TRUE))
colSums(data2_species1[, -1], na.rm=TRUE) ##excluding species not present in the sites with complete environmental data, and two species with abundances <100

data2_species1<- subset(data2_species1, select= -c(Unknown, Folsomotoma.octooculata, Friesea.tilbrooki, Archistoma.brucei, Tullbergia.antarctica, Megalothorax.sp.))
data2_species1[is.na(data2_species1)]<- 0 #replace NAs in data with 0 counts

data2_sites1<- unique(data2_sites) #unique site data
data2<- merge(data2_species1, data2_sites1, by= "Site.code")

rm(data2_sites, data2_sites1, data2_species, data2_species1)



###Removing Sooty Valley site (single site) from analysis because only one site surveyed in that area with complete environmental data, and Locality is used as a predictor of community composition in this analysis
data2$Habitat_simplified<- factor(data2$Habitat_simplified)
data2<- subset(data2, !data2$Locality== "Sooty Valley")
data2$Locality<- factor(data2$Locality)

######
data2_species<- subset(data2, select= c(Cryptogygus.antarcticus,Cryptopygus.tricuspis, Mucrosomia.caeca,Folsomotoma.punctata, Isotoma.sp...small.white., Tullbergia.bisetosa,  Friesea.bispinosa, Tullbergia.templei))
data2_sites<- subset(data2, select= c(Site.code, Latitude_final, Longitude_final, Location, Locality, Site.name, Location_code,  Water_Scale, Exposure_Scale, Slope_deg, Aspect_deg, Altitude_masl,  Blocks...25cm., Pebbles..5cm...25cm., Gravel..0.2...5cm., Sand.and.finer.material...0.2cm., Location_code, Habitat_code, Habitat_type, Habitat_simplified, Aspect_deg_fromSouth))

boxplot(data2_species, horizontal = TRUE, main= "Abundance")
sprindat <- mvabund(data2_species)

meanvar.plot(sprindat)


library(corrplot)
corr_data<- cor(subset(data2_sites, select= c(Aspect_deg_fromSouth, Altitude_masl, Slope_deg)))
corrplot(corr_data, method= "number")
str(data2_sites)

heard.nb <- manyglm(sprindat ~ Habitat_simplified + Aspect_deg_fromSouth + Altitude_masl+ Slope_deg + Locality +Exposure_Scale + Water_Scale, family = "negative.binomial", data= data2_sites)
drop1(heard.nb, test = "Chi") ##remove Water scale

heard.nb <- manyglm(sprindat ~ Habitat_simplified + Aspect_deg_fromSouth + Altitude_masl+ Slope_deg + Locality + Exposure_Scale, family = "negative.binomial", data= data2_sites)
drop1(heard.nb, test = "Chi") ##remove Aspect

heard.nb <- manyglm(sprindat ~ Habitat_simplified  + Altitude_masl+ Slope_deg + Locality + Exposure_Scale, family = "negative.binomial", data= data2_sites)
drop1(heard.nb, test = "Chi")

##check mean-variance assumption: Little pattern suggests that the quadratic mean–variance assumption implicit in using family “negative binomial” is plausible. (see Wang et al. 2013 Methods in Ecology and Evolution)
## log-linearity assumption: a trend in size of residuals at different fitted values (e.g. a ‘U-shape’) would suggest a violation of the log-linearity assumption.
plot(heard.nb)

heard.nb_sim <- manyglm(sprindat ~ Habitat_simplified + Altitude_masl + Locality, family = "negative.binomial", data= data2_sites)
anova(heard.nb_sim, heard.nb) ##tests whether the model with slope and exposure explains any additional variation not captured by the habitat model alone

anova.manyglm(heard.nb, p.uni ="adjusted", resamp= "montecarlo", test= "LR")


saveRDS(heard.nb, file = "/MVAadund_abundance_nb_v1.rds")


coefplot.manyglm(heard.nb, which.Xcoef=2:8, mfrow= c(2,4))                            
coefplot.manyglm(heard.nb, which.Xcoef=9:14, mfrow= c(2,4))

